@@ -260,6 +260,12 @@ class Object(object):
 
        The unique identifier for this object.  (Read-only)
 
+    .. attribute:: alive
+
+       Whether or not the object is alive.  An object is considered to
+       be "alive" from the time it is first added to a room to the time
+       it is destroyed.  (Read-only)
+
     .. attribute:: mask
 
        The current mask used for non-rectangular collision detection.
@@ -369,20 +375,29 @@ class Object(object):
         # TODO
 
     def destroy(self):
-        """Destroy the object."""
+        """Destroy the object.
+
+        This removes the object from all rooms in the game, deletes its
+        reference in :attr:`sge.game.objects`, and marks it as "dead".
+
+        """
         # TODO
 
     def event_create(self):
         """Create event.
 
-        Called when the object is created.  It is always called after
-        any room start events occurring at the same time.
+        Called right after the object is created.  It is always called
+        after any room start events occurring at the same time.
 
         """
         pass
 
     def event_destroy(self):
-        """Destroy event."""
+        """Destroy event.
+
+        Called right after the object is destroyed.
+
+        """
         pass
 
     def event_begin_step(self, time_passed, delta_mult):
